
/* Chrysalide - Outil d'analyse de fichiers binaires
 * archbase.c - équivalent Python du fichier "arch/archbase.h"
 *
 * Copyright (C) 2012-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "archbase.h"





/* Classe 'arch.vmpa' pour Python */
typedef PyLongObject py_vmpa;



/* Fournit le type d'objet 'arch.vmpa' pour Python. */
static PyTypeObject *get_arch_vmpa_type(void);






/******************************************************************************
*                                                                             *
*  Paramètres  : value = adresse à convertir en objet Python.                 *
*                                                                             *
*  Description : Crée un nouvel objet Python de type 'py_vmpa'.               *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

PyObject *py_vmpa_new_from_existing(vmpa_t value)
{
    return PyLong_FromLongLong(value);

}














/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Fournit le type d'objet 'arch.vmpa' pour Python.             *
*                                                                             *
*  Retour      : Adresse du type vivant à manipuler.                          *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static PyTypeObject *get_arch_vmpa_type(void)
{
    return &PyLong_Type;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : module = module dont la définition est à compléter.          *
*                                                                             *
*  Description : Ajoute l'objet 'arch.vmpa' au module Python.                 *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool add_arch_vmpa_to_python_module(PyObject *module)
{
    PyTypeObject *py_vmpa_type;             /* Type défini pour Python     */
    int ret;                                /* Bilan d'un appel            */

    py_vmpa_type = get_arch_vmpa_type();

    if (PyType_Ready(py_vmpa_type) < 0)
        return false;

    Py_INCREF(py_vmpa_type);
    ret = PyModule_AddObject(module, "Vmpa", (PyObject *)py_vmpa_type);

    return (ret == 0);

}
